@@ -1,9 +1,8 @@
 import os
 
-from six.moves.urllib_parse import urljoin, urlparse
-
 import click
 import requests
+from six.moves.urllib_parse import urljoin, urlparse
 
 from . import messages
 from .utils import create_temp_dir, get_user_agent
@@ -34,15 +33,23 @@ class SingleHostSession(requests.Session):
         for key, value in kwargs.items():
             setattr(self, key, value)
 
-    def request(self, method, url, *args, **kwargs):
+    def request(self, method, url, v3_compatibilty=False, *args, **kwargs):
         url = urljoin(self.host, url)
-        return super(SingleHostSession, self).request(method, url, *args, **kwargs)
+        if v3_compatibilty:
+            # V3 compatibility hack
+            url = url.replace("control", "api", 1)
+        return super(SingleHostSession, self).request(
+            method, url, *args, **kwargs
+        )
 
 
 class APIRequestError(click.ClickException):
     def show(self, file=None):
         click.secho(
-            f"\nError: {self.format_message()}", file=file, err=True, fg="red"
+            "\nError: {}".format(self.format_message()),
+            file=file,
+            err=True,
+            fg="red",
         )
 
 
@@ -51,6 +58,7 @@ class APIRequest(object):
     default_error_message = messages.SERVER_ERROR
     response_code_error_map = {
         requests.codes.forbidden: messages.AUTH_INVALID_TOKEN,
+        requests.codes.unauthorized: messages.AUTH_INVALID_TOKEN,
         requests.codes.not_found: messages.RESOURCE_NOT_FOUND_ANONYMOUS,
     }
 
@@ -60,7 +68,14 @@ class APIRequest(object):
     headers = {}
 
     def __init__(
-        self, session, url=None, url_kwargs=None, data=None, files=None, *args, **kwargs
+        self,
+        session,
+        url=None,
+        url_kwargs=None,
+        data=None,
+        files=None,
+        *args,
+        **kwargs
     ):
         self.session = session
         if url:
@@ -112,7 +127,10 @@ class APIRequest(object):
                 *args,
                 **kwargs
             )
-        except (requests.exceptions.ConnectionError, requests.exceptions.Timeout) as e:
+        except (
+            requests.exceptions.ConnectionError,
+            requests.exceptions.Timeout,
+        ) as e:
             raise click.ClickException(messages.NETWORK_ERROR_MESSAGE + str(e))
 
         return self.verify(response)
@@ -371,3 +389,20 @@ class SetCustomEnvironmentVariablesRequest(JsonResponse, APIRequest):
 
 class RepositoryRequest(JsonResponse, APIRequest):
     url = "/api/v2/repositories/?website={website_id}"
+
+
+class APIV3Request(APIRequest):
+    def request(self, *args, **kwargs):
+        return super(APIV3Request, self).request(
+            v3_compatibilty=True, *args, **kwargs
+        )
+
+
+class LogRequest(JsonResponse, APIV3Request):
+    url = "/apps/v3/environments/{environment_uuid}/logs/"
+    method = "GET"
+
+
+class EnvironmentRequest(JsonResponse, APIV3Request):
+    url = "/apps/v3/environments/{environment_uuid}/"
+    method = "GET"
