@@ -15,7 +15,7 @@ import requests
 from divio_cli.utils import get_local_git_remotes
 
 from .. import settings
-from ..cloud import get_divio_host
+from ..cloud import get_divio_zone
 from ..utils import (
     check_call,
     check_output,
@@ -27,9 +27,10 @@ from ..utils import (
     pretty_size,
 )
 from . import utils
+from .utils import get_project_home, get_project_settings
 
 
-DEFAULT_GIT_HOST = "git@git.{divio_host}"
+DEFAULT_GIT_HOST = "git@git.{divio_zone}"
 GIT_CLONE_URL = "{git_host}:{project_slug}.git"
 
 
@@ -37,43 +38,62 @@ DEFAULT_DUMP_FILENAME = "local_db.sql"
 DEFAULT_SERVICE_PREFIX = "DEFAULT"
 
 
-def get_git_host():
-    git_host = os.environ.get("ALDRYN_GIT_HOST")
+def get_git_host(zone=None):
+    try:
+        git_host = get_project_settings(get_project_home()).get(
+            "git_host", None
+        )
+    except click.ClickException:
+        git_host = None
+
+    if not git_host:
+        git_host = os.environ.get("DIVIO_GIT_HOST")
+
     if git_host:
         click.secho("Using custom git host {}\n".format(git_host), fg="yellow")
     else:
-        git_host = DEFAULT_GIT_HOST.format(divio_host=get_divio_host())
+        if not zone:
+            zone = get_divio_zone()
+        git_host = DEFAULT_GIT_HOST.format(divio_zone=zone)
     return git_host
 
 
-def get_git_clone_url(slug, website_id, client):
+def get_git_clone_url(slug, website_id, client, zone=None):
     remote_dsn = client.get_repository_dsn(website_id)
     # if we could get a remote_dsn, us it! Otherwise, its probably a default git setup
     if remote_dsn:
         return remote_dsn
     # TODO: mirrors should fail here
-    return GIT_CLONE_URL.format(git_host=get_git_host(), project_slug=slug)
+    return GIT_CLONE_URL.format(
+        git_host=get_git_host(zone=zone), project_slug=slug
+    )
 
 
-def clone_project(website_slug, path, client):
+def clone_project(website_slug, path, client, zone=None, branch=None):
     click.secho("\ncloning project repository", fg="green")
     website_id = client.get_website_id_for_slug(website_slug)
 
     website_git_url = get_git_clone_url(
-        website_slug, website_id, client=client
+        website_slug, website_id, client=client, zone=zone
     )
-    clone_args = ["git", "clone", website_git_url]
+    clone_args = ["git", "clone"]
+    if branch:
+        clone_args.append(f"-b{branch}")
+    clone_args.append(website_git_url)
     if path:
         clone_args.append(path)
 
     check_call(clone_args)
 
 
-def configure_project(website_slug, path, client):
+def configure_project(website_slug, path, client, zone=None):
     website_id = client.get_website_id_for_slug(website_slug)
 
+    if not zone:
+        zone = get_divio_zone()
+
     # create configuration file
-    website_data = {"id": website_id, "slug": website_slug}
+    website_data = {"id": website_id, "slug": website_slug, "zone": zone}
     if os.path.exists(os.path.join(path, settings.ALDRYN_DOT_FILE)):
         path = os.path.join(path, settings.ALDRYN_DOT_FILE)
     else:
@@ -102,7 +122,7 @@ def configure_project(website_slug, path, client):
     click.secho(
         "Git remote:         {}".format(
             click.style(
-                get_git_clone_url(website_slug, website_id, client),
+                get_git_clone_url(website_slug, website_id, client, zone=zone),
                 fg="bright_green",
             )
         )
@@ -194,7 +214,7 @@ def setup_website_containers(
 
 
 def create_workspace(
-    client, website_slug, stage, path=None, force_overwrite=False
+    client, website_slug, stage, path=None, force_overwrite=False, zone=None
 ):
     click.secho("Creating workspace", fg="green")
 
@@ -220,11 +240,22 @@ def create_workspace(
             click.secho("Aborting", fg="red")
             sys.exit(1)
 
+    website_id = client.get_website_id_for_slug(website_slug)
+    env = client.get_environment(website_id, stage)
+
     # clone git project
-    clone_project(website_slug=website_slug, path=path, client=client)
+    clone_project(
+        website_slug=website_slug,
+        path=path,
+        client=client,
+        zone=zone,
+        branch=env["branch"],
+    )
 
     # check for new baseproject + add configuration file
-    configure_project(website_slug=website_slug, path=path, client=client)
+    configure_project(
+        website_slug=website_slug, path=path, client=client, zone=zone
+    )
 
     # setup docker website containers
     setup_website_containers(client=client, stage=stage, path=path)
@@ -492,19 +523,28 @@ class DatabaseImportBase(object):
 
         # TODO: use same dump-type detection like server side on db-api
         try:
-            subprocess.call(
-                (
+            check_call(
+                [
                     "docker",
                     "exec",
                     db_container_id,
                     "/bin/bash",
                     "-c",
                     restore_command,
-                ),
+                ],
                 env=get_subprocess_env(),
+                catch=False,
             )
-        except subprocess.CalledProcessError:
-            pass
+        except subprocess.CalledProcessError as exc:
+            click.secho(
+                "Could not restore the database dump. This is likely a "
+                "configuration issue."
+                "\n\nSee https://docs.divio.com/en/latest/reference/docker-docker-compose/#services-defined-in-docker-compose-yml\n\n"
+                "The executed command was:\n"
+                "  {command}".format(command=" ".join(exc.cmd)),
+                fg="red",
+            )
+            sys.exit(1)
 
     def restore_db_mysql(self, db_container_id):
         restore_command = self.get_db_restore_command(self.db_type)
@@ -1234,7 +1274,7 @@ def open_project(open_browser=True):
     return addr
 
 
-def configure(client):
+def configure(client, zone=None):
     if click.confirm(
         "This action will overwrite the local Divio configuration file for your project or create a new one. Do you want to continue?"
     ):
@@ -1242,7 +1282,10 @@ def configure(client):
             "Please enter the application slug of the local project", type=str
         )
         configure_project(
-            website_slug=website_slug, path=os.getcwd(), client=client
+            website_slug=website_slug,
+            path=os.getcwd(),
+            client=client,
+            zone=zone,
         )
 
 
