@@ -12,7 +12,6 @@ from math import log
 import click
 import requests
 from packaging import version
-from six import PY2
 from six.moves.urllib_parse import urljoin
 from tabulate import tabulate
 
@@ -63,26 +62,6 @@ def create_temp_dir():
     return tempfile.mkdtemp(prefix="tmp_divio_cli_")
 
 
-def get_bytes_io(*args, **kwargs):
-    if PY2:
-        from StringIO import StringIO
-
-        cls = StringIO
-    else:
-        from io import BytesIO
-
-        cls = BytesIO
-    return cls(*args, **kwargs)
-
-
-def get_string_io(*args, **kwargs):
-    if PY2:
-        from StringIO import StringIO
-    else:
-        from io import StringIO
-    return StringIO(*args, **kwargs)
-
-
 def tar_add_stringio(tar, string_io, name):
     bytes_io = io.BytesIO(string_io.getvalue().encode())
     return tar_add_bytesio(tar, bytes_io, name)
@@ -359,7 +338,7 @@ def get_local_git_remotes():
 
 def needs_legacy_migration():
     try:
-        check_output(["command", "-v", "start"])
+        check_output(["command", "-v", "start"], catch=False)
         return True
     except Exception:
         return False
